@@ -7,7 +7,6 @@ import (
 
 	"github.com/projectdiscovery/nuclei/v3/pkg/fuzz/dataformat"
 	"github.com/projectdiscovery/retryablehttp-go"
-	mapsutil "github.com/projectdiscovery/utils/maps"
 	urlutil "github.com/projectdiscovery/utils/url"
 )
 
@@ -38,12 +37,18 @@ func (q *Path) Parse(req *retryablehttp.Request) (bool, error) {
 
 	splitted := strings.Split(req.Path, "/")
 	values := make(map[string]interface{})
-	for i := range splitted {
-		pathTillNow := strings.Join(splitted[:i+1], "/")
-		if pathTillNow == "" {
+	for i, segment := range splitted {
+		if segment == "" && i == 0 {
+			// Skip the first empty segment from leading "/"
 			continue
 		}
-		values[strconv.Itoa(i)] = pathTillNow
+		if segment == "" {
+			// Skip any other empty segments
+			continue
+		}
+		// Use 1-based indexing and store individual segments
+		key := strconv.Itoa(len(values) + 1)
+		values[key] = segment
 	}
 	q.value.SetParsed(dataformat.KVMap(values), "")
 	return true, nil
@@ -64,7 +69,7 @@ func (q *Path) Iterate(callback func(key string, value interface{}) error) (err
 // SetValue sets a value in the component
 // for a key
 func (q *Path) SetValue(key string, value string) error {
-	escaped := urlutil.ParamEncode(value)
+	escaped := urlutil.PathEncode(value)
 	if !q.value.SetParsedValue(key, escaped) {
 		return ErrSetValue
 	}
@@ -82,40 +87,48 @@ func (q *Path) Delete(key string) error {
 // Rebuild returns a new request with the
 // component rebuilt
 func (q *Path) Rebuild() (*retryablehttp.Request, error) {
-	originalValues := mapsutil.Map[string, any]{}
-	splitted := strings.Split(q.req.Path, "/")
-	for i := range splitted {
-		pathTillNow := strings.Join(splitted[:i+1], "/")
-		if pathTillNow == "" {
-			continue
-		}
-		originalValues[strconv.Itoa(i)] = pathTillNow
+	// Get the original path segments
+	originalSplitted := strings.Split(q.req.Path, "/")
+	
+	// Create a new slice to hold the rebuilt segments
+	rebuiltSegments := make([]string, 0, len(originalSplitted))
+	
+	// Add the first empty segment (from leading "/")
+	if len(originalSplitted) > 0 && originalSplitted[0] == "" {
+		rebuiltSegments = append(rebuiltSegments, "")
 	}
-
-	originalPath := q.req.Path
-	lengthSplitted := len(q.value.parsed.Map)
-	for i := lengthSplitted; i > 0; i-- {
-		key := strconv.Itoa(i)
-
-		original, ok := originalValues.GetOrDefault(key, "").(string)
-		if !ok {
+	
+	// Process each segment
+	segmentIndex := 1 // 1-based indexing for our stored values
+	for i := 1; i < len(originalSplitted); i++ {
+		originalSegment := originalSplitted[i]
+		if originalSegment == "" {
+			// Skip empty segments
 			continue
 		}
-
-		new, ok := q.value.parsed.Map.GetOrDefault(key, "").(string)
-		if !ok {
-			continue
+		
+		// Check if we have a replacement for this segment
+		key := strconv.Itoa(segmentIndex)
+		if newValue, exists := q.value.parsed.Map.GetOrDefault(key, "").(string); exists && newValue != "" {
+			rebuiltSegments = append(rebuiltSegments, newValue)
+		} else {
+			rebuiltSegments = append(rebuiltSegments, originalSegment)
 		}
-
-		if new == original {
-			// no need to replace
-			continue
-		}
-
-		originalPath = strings.Replace(originalPath, original, new, 1)
+		segmentIndex++
+	}
+	
+	// Join the segments back into a path
+	rebuiltPath := strings.Join(rebuiltSegments, "/")
+	
+	if unescaped, err := urlutil.PathDecode(rebuiltPath); err == nil {
+		// this is handle the case where anyportion of path has url encoded data
+		// by default the http/request official library will escape/encode special characters in path
+		// to avoid double encoding we unescape/decode already encoded value
+		//
+		// if there is a invalid url encoded value like %99 then it will still be encoded as %2599 and not %99
+		// the only way to make sure it stays as %99 is to implement raw request and unsafe for fuzzing as well
+		rebuiltPath = unescaped
 	}
-
-	rebuiltPath := originalPath
 
 	// Clone the request and update the path
 	cloned := q.req.Clone(context.Background())
