@@ -5,6 +5,7 @@ import (
 	"fmt"
 	"net"
 	"net/url"
+	"time"
 
 	"github.com/go-sql-driver/mysql"
 	"github.com/pkg/errors"
@@ -174,10 +175,16 @@ func initDialers(options *types.Options) error {
 
 	networkPolicy, _ := networkpolicy.New(*npOptions)
 
+	httpClientPool := mapsutil.NewSyncLockMap(
+		// evicts inactive httpclientpool entries after 24 hours
+		// of inactivity (long running instances)
+		mapsutil.WithEviction[string, *retryablehttp.Client](24*time.Hour, 12*time.Hour),
+	)
+
 	dialersInstance := &Dialers{
 		Fastdialer:             dialer,
 		NetworkPolicy:          networkPolicy,
-		HTTPClientPool:         mapsutil.NewSyncLockMap[string, *retryablehttp.Client](),
+		HTTPClientPool:         httpClientPool,
 		LocalFileAccessAllowed: options.AllowLocalFileAccess,
 	}
 
