@@ -1,22 +1,15 @@
 package networkclientpool
 
 import (
+	"fmt"
+
 	"github.com/projectdiscovery/fastdialer/fastdialer"
 	"github.com/projectdiscovery/nuclei/v3/pkg/protocols/common/protocolstate"
 	"github.com/projectdiscovery/nuclei/v3/pkg/types"
 )
 
-var (
-	normalClient *fastdialer.Dialer
-)
-
 // Init initializes the clientpool implementation
 func Init(options *types.Options) error {
-	// Don't create clients if already created in the past.
-	if normalClient != nil {
-		return nil
-	}
-	normalClient = protocolstate.Dialer
 	return nil
 }
 
@@ -32,10 +25,12 @@ func (c *Configuration) Hash() string {
 
 // Get creates or gets a client for the protocol based on custom configuration
 func Get(options *types.Options, configuration *Configuration /*TODO review unused parameters*/) (*fastdialer.Dialer, error) {
-
 	if configuration != nil && configuration.CustomDialer != nil {
 		return configuration.CustomDialer, nil
 	}
-
-	return normalClient, nil
+	dialers := protocolstate.GetDialersWithId(options.ExecutionId)
+	if dialers == nil {
+		return nil, fmt.Errorf("dialers not initialized for %s", options.ExecutionId)
+	}
+	return dialers.Fastdialer, nil
 }
